@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Config;
 # ABSTRACT: Load config files for Authentication Milter
 use strict;
 use warnings;
-our $VERSION = '2.20180328'; # VERSION
+our $VERSION = '2.20180329'; # VERSION
 
 use Mail::Milter::Authentication;
 use Module::Load;
@@ -112,35 +112,21 @@ sub load_file {
 
 
 sub process_config {
-    my ( $config ) = @_;
 
-    if ( exists( $config->{ 'config_processor' } ) ) {
-
-        # Try and load the handler
-        my $handler = $config->{ 'config_processor' };
-        if ( ! is_loaded ( $handler ) ) {
-            eval { load $handler; };
-            if ( my $error = $@ ) {
-                warn "Error loading config processor module: $error";
-                return $config;
-            }
+    if ( exists( $CONFIG->{ '_external_callback_processor' } ) ) {
+        if ( $CONFIG->{ '_external_callback_processor' }->can( 'process_config' ) ) {
+            $CONFIG->{ '_external_callback_processor' }->process_config( $CONFIG );
         }
-
-        eval{
-            no strict 'refs'; ## no critic;
-            $config = $handler->process( $config );
-        };
-
     }
 
-    return $config;
+    return $CONFIG;
 }
 
 
 sub get_config {
 
     if ( $CONFIG ) {
-        return process_config( $CONFIG );
+        return process_config();
     }
 
     my $file = $PREFIX . '/authentication_milter.json';
@@ -172,9 +158,26 @@ sub get_config {
     my $protocol = $config->{'protocol'} || 'milter';
     $config->{'protocol'} = $protocol;
 
+    # Have we specified an external callback processor?
+    if ( exists( $config->{ 'external_callback_processor' } ) ) {
+        # Try and load the handler
+        my $handler = $config->{ 'external_callback_processor' };
+        warn "Loading external callback processor $handler\n";
+        if ( ! is_loaded ( $handler ) ) {
+            eval {
+                no strict 'refs'; ## no critic;
+                load $handler;
+                $config->{ '_external_callback_processor' } = $handler->new();
+            };
+            if ( my $error = $@ ) {
+                warn "Error loading config processor module: $error";
+            }
+        }
+    }
+
     $CONFIG = $config;
 
-    return process_config( $config );
+    return process_config();
 
 }
 
@@ -192,7 +195,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 2.20180328
+version 2.20180329
 
 =head1 SYNOPSIS
 
@@ -227,15 +230,18 @@ Internal function used to load the config from /etc/authentication_milter.json
 
 Process the loaded config with the callback if required.
 
-This is the name of a Module to load, the process method of the module
-will be called with $config as the argument, it expects the processed config
-to be returned.
+This is the name of a Module to load, the process_config method of the instantiated object
+will be called with $config as the argument.g
 
     package ConfigProcessor;
 
-    sub process {
+    sub new {
+        ...
+    }
+
+    sub process_config {
         my ( $self, $config ) = @_;
-        return $config;
+        return;
     }
 
     1;
